.. _require_oracle_jdk_module:

:mod:`fabtools.require.oracle_jdk`
-----------------------------------

.. automodule:: fabtools.require.oracle_jdk
    :members:

    .. seealso:: :ref:`oracle_jdk_module`
